@@ -5,6 +5,6 @@ import numpy
 
 setup(
     cmdclass = {'build_ext': build_ext},
-    ext_modules = [Extension("Z_shooting", ["Z_shooting.pyx"],)],
-    include_dirs=[numpy.get_include(),],
+    ext_modules = [Extension("Z_shooting", ["Z_shooting.c"],)],
+    include_dirs=[numpy.get_include(),'.', ],
 )
